# Boilerplate functions

**Last Updated with Central 2.5.6 9/20/2022 (internal)**

- The files in this directory contain python functions for each API endpoint available in Aruba Central.
- The functions are designed to fit within the framework used by centralcli, but can easily be adjusted to suite other needs.
- The functions are generated by a script based on the API schema files, those schema files have some inaccuracies.
- Not all functions will work without tweaking.
- Primary purpose of these is to save time as they are used in the CLI.

These methods can be tested with the CLI, and auto-completion works as well (will provide a list of available functions).  <br>Provide the name of the function followed by any arguments the function takes (space seperated), then keyword arguments in the form key=value<br>
`cencli test method <function_name> [arg1 arg2 arg3] [keyword1=value1 keyword2=value2]`

 > If an argument accepts a list provide that in the form `'[item1,item2,item3]'` Note it's wrapped in single quotes (prevent shell issues with `[]` which are reserved in many shells)

btw: `get`, `post`... are all available as well.  The first argument for those functions is the url (past the base url):<br>
`cencli test method get /central/v2/sites`
